import java.awt.event.*;
import java.awt.*;
import java.net.URL;

/**
 * Splash screen class.
 * 
 * Displays the splash screen for x quanta then closes.
 * 
 * @author Team NAH
 * @version Spring 2006
 */
public final class SplashScreen extends Frame {

	private final String fImageId;

	private MediaTracker fMediaTracker;

	private Image fImage;

	public SplashScreen(String aImageId) {
		if (aImageId == null || aImageId.trim().length() == 0) {
			throw new IllegalArgumentException(
					"Image Id does not have content.");
		}
		fImageId = aImageId;
	}

	public void splash() {
		initImageAndTracker();
		setSize(fImage.getWidth(null), fImage.getHeight(null));

		fMediaTracker.addImage(fImage, 0);
		try {
			fMediaTracker.waitForID(0);
		} catch (InterruptedException ie) {
			System.out.println("Cannot track image load.");
		}
		SplashWindow splashWindow = new SplashWindow(this, fImage);
	}

	private void initImageAndTracker() {
		fMediaTracker = new MediaTracker(this);
		URL imageURL = SplashScreen.class.getResource(fImageId);
		fImage = Toolkit.getDefaultToolkit().getImage(imageURL);
	}

	private class SplashWindow extends Window {
		private Image fImage;

		public SplashWindow(Frame aParent, Image aImage) {
			super(aParent);
			fImage = aImage;
			setSize(fImage.getWidth(null), fImage.getHeight(null));
			setLocationRelativeTo(null);
			setVisible(true);
		}

		public void paint(Graphics graphics) {
			if (fImage != null) {
				graphics.drawImage(fImage, 0, 0, this);
			}
		}
	}
}
